@@ -41,10 +41,6 @@
 #include "gnome-uidefs.h"
 #include "gnometypebuiltins.h"
 
-#ifndef GNOME_ENABLE_DEBUG
-#define GNOME_ENABLE_DEBUG /* to be sure */
-#endif
-
 struct _GnomeAppBarPrivate
 {
   /* Private; there's no guarantee on the type of these in the
@@ -140,11 +136,6 @@ entry_delete_text_cb(GtkWidget * entry, gint start,
 
   if (ab->_priv->prompt == NULL) return; /* not prompting, so don't
 				     interfere. */
-#ifdef GNOME_ENABLE_DEBUG
-    g_print("Start is %d, stop is %d, start of editable is %d\n",
-	    start, stop, ab->_priv->editable_start);
-#endif
-
   if (start < ab->_priv->editable_start) {
     /* Block the signal, since it's trying to delete text
        that shouldn't be deleted. */
@@ -166,11 +157,6 @@ entry_insert_text_cb  (GtkEditable    *entry,
 
   pos = gtk_editable_get_position(entry);
 
-#ifdef GNOME_ENABLE_DEBUG
-    g_print("Position is %d, start of editable is %d\n",
-	    pos, ab->_priv->editable_start);
-#endif
-
   if (pos < ab->_priv->editable_start) {
 
     /*    gtk_editable_set_position(entry, ab->_priv->editable_start); */
@@ -326,7 +312,6 @@ gnome_appbar_get_response    (GnomeAppBar * appbar)
 {
   g_return_val_if_fail(appbar != NULL, NULL);
   g_return_val_if_fail(appbar->_priv->interactive, NULL);
-  g_return_val_if_fail(appbar->_priv->prompt != NULL, NULL);
 
   /* This returns an allocated string. */
   return gtk_editable_get_chars(GTK_EDITABLE(appbar->_priv->status),
@@ -615,7 +600,7 @@ gnome_appbar_constructor (GType                  type,
    */
   if (has_progress &&
       /* FIXME: this should listen to changes! */
-      ! gnome_gconf_get_bool ("/desktop/gnome/interface/statusbar-meter-on-right"))
+      ! gnome_gconf_get_bool ("/desktop/gnome/interface/statusbar_meter_on_right"))
     gtk_box_pack_start (box, ab->_priv->progress, FALSE, FALSE, 0);
 
   if ( has_status ) {
@@ -658,7 +643,7 @@ gnome_appbar_constructor (GType                  type,
 
   if (has_progress &&
       /* FIXME: this should listen to changes! */
-      gnome_gconf_get_bool ("/desktop/gnome/interface/statusbar-meter-on-right"))
+      gnome_gconf_get_bool ("/desktop/gnome/interface/statusbar_meter_on_right"))
     gtk_box_pack_start (box, ab->_priv->progress, FALSE, FALSE, 0);
 
   if (ab->_priv->status) gtk_widget_show (ab->_priv->status);
