@@ -250,11 +250,16 @@ static int
 gil_get_items_per_line (Gil *gil)
 {
 	GnomeIconListPrivate *priv;
+	int available_width;
 	int items_per_line;
 
 	priv = gil->_priv;
 
-	items_per_line = GTK_WIDGET (gil)->allocation.width / (priv->icon_width + priv->col_spacing);
+	available_width = GTK_WIDGET (gil)->allocation.width - 2 * DEFAULT_COL_SPACING;
+
+	items_per_line = ((available_width + priv->col_spacing)
+			  / (priv->icon_width + priv->col_spacing));
+
 	if (items_per_line == 0)
 		items_per_line = 1;
 
@@ -311,11 +316,9 @@ gil_place_icon (Gil *gil, Icon *icon, int x, int y, int icon_height)
 				       NULL);
 	}
 
-
 	gnome_icon_text_item_setxy (icon->text,
 				    x,
 				    y + icon_height + priv->text_spacing);
-
 }
 
 static void
@@ -1297,7 +1300,7 @@ gnome_icon_list_remove (GnomeIconList *gil, int pos)
 
 	if (priv->icons >= priv->focus_icon)
 		priv->focus_icon = -1;
-	
+
 	if (priv->last_selected_icon == icon)
 		priv->last_selected_icon = NULL;
 
@@ -1339,6 +1342,7 @@ gnome_icon_list_clear (GnomeIconList *gil)
 	priv->selection = NULL;
 	g_array_set_size(priv->icon_list, 0);
 	priv->icons = 0;
+	priv->focus_icon = -1;
 	priv->last_selected_idx = -1;
 	priv->last_selected_icon = NULL;
 
@@ -1575,36 +1579,29 @@ real_move_cursor (Gil *gil, GtkDirectionType dir, gboolean clear_selection)
 		if (priv->focus_icon + 1 < priv->icons &&
 		    priv->focus_icon % items_per_line != (items_per_line - 1))
 			new_focus_icon++;
-		else
-			return;
 		break;
 
 	case GTK_DIR_LEFT:
 		if (priv->focus_icon - 1 >= 0 &&
 		    priv->focus_icon % items_per_line != 0)
 			new_focus_icon--;
-		else
-			return;
 		break;
 
 	case GTK_DIR_DOWN:
 		if (priv->focus_icon + items_per_line < priv->icons)
 			new_focus_icon += items_per_line;
-		else
-			return;
 		break;
 
 	case GTK_DIR_UP:
 		if (priv->focus_icon - items_per_line >= 0)
 			new_focus_icon -= items_per_line;
-		else
-			return;
 		break;
 	default:
 		break;
 	}
-
-	if (clear_selection) {
+	
+	if (clear_selection &&
+	    g_array_index (priv->icon_list, Icon *, new_focus_icon)->selected == FALSE) {
 		gnome_icon_list_unselect_all (gil);
 		gnome_icon_list_select_icon (gil, new_focus_icon);
 	}
@@ -2021,8 +2018,16 @@ gnome_icon_list_constructor (GType                  type,
 static gint
 gil_focus_in (GtkWidget *widget, GdkEventFocus *event)
 {
+	Gil *gil;
+
+	gil = GIL (widget);
+	
 	GTK_WIDGET_SET_FLAGS (widget, GTK_HAS_FOCUS);
 
+	if (gil->_priv->icons > 0 && gil->_priv->focus_icon == -1) {
+		gnome_icon_list_focus_icon (gil, 0);
+	}
+	
 	gtk_widget_queue_draw (widget);
 
 	return FALSE;
